Merging licht cache passes is very slow

Hi,

it’s a problem since a long time here at VfR and I ask, is it a problem at Vray for max too?

The merging process seems to be single threaded. Maybe it’s possible, if for example 32 passes are calculated, that in a first step 16 cores are merging pairs of passes, in the next step 16 cores are merging pairs of the last merged passes … .

Also my impression is that some 3D scenes cause a slower merging/filtering of the LC passes. Can I optimize my scenes for faster calculation?

Regards,
Micha

Yes, this is a problem in 3ds Max too. The light cache merge phase is not multithreaded - we need to work on that. Increasing the light cache sample size will make this phase faster.

Best regards,
Vlado

Could be great, if the multcores could be supported. I did a simple test, disabled final rendering and set a very fast IM, LC 2000 subdivs and one time 4 num. phases and one time 32. The speed was 35s vs. 60s, so less num. phases allow a faster rendering for now. Could be great to profit by all cores.

Thanks,
Micha

Hi Vlado,

during a project start I found a good example, how much longer are the render times by the LC passes. This simple image has following times:

* LC 4s
* merging 20s
* filtering 3s
* IM 5s
* final pass 3s

So we have 12 s for render the passes and 23 s for merging/filtering the LC. The rendering is 3x times slower by merging/filtering, a hugh potential for saving render time, important for rendering animations. Do you thing the Vray code could be refined soon? Looks like a not so strong problem. :wink:

++
Micha

I’ll see what can be done about it… it should not be too hard, I think.

Best regards,
Vlado